﻿//-----------------------------------------------------------------------------
//
// Copyright (c) Microsoft Corporation.  All Rights Reserved.
// This code is licensed under the Microsoft Public License.
// THIS CODE IS PROVIDED *AS IS* WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING ANY
// IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR
// PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.
//
//-----------------------------------------------------------------------------
using System;
using System.IO;
using Microsoft.Cci;

namespace PeToMse {
  class Program {
    static void Main(string[] args) {
      if (args == null || args.Length == 0) {
        Console.WriteLine("usage: peToMef [path]fileName.ext");
        return;
      }
      using (var host = new PeReader.DefaultHost()) {
        IModule/*?*/ module = host.LoadUnitFrom(args[0]) as IModule;
        if (module == null || module == Dummy.Module || module == Dummy.Assembly) {
          Console.WriteLine(args[0] + " is not a PE file containing a CLR module or assembly.");
          return;
        }

        PdbReader/*?*/ pdbReader = null;
        string pdbFile = Path.ChangeExtension(module.Location, "pdb");
        if (File.Exists(pdbFile)) {
          Stream pdbStream = File.OpenRead(pdbFile);
          pdbReader = new PdbReader(pdbStream, host);
        }
        using (pdbReader) {
          string txtFile = Path.ChangeExtension(pdbFile, "mse");
          using(var writer = new StreamWriter(txtFile)) {
         //   var writer = Console.Out;

            writer.WriteLine("(");
              var csSourceEmitter = new SourceEmitter(writer, host, pdbReader);
              csSourceEmitter.Visit(module);
            writer.WriteLine(")");
                  }
        }
      }
    }
  }

  class Base
  {
      public void CC9()
      {
          for (int i = 0; i < 5; i++)
          {}
          if (DateTime.Now.Ticks > 123) { }
          else { }
      }
  }

  class Child : Base
  {
  }

  class GrandChild : Child
  {
  }

}
